/*  adjust.C   */
/*  Copyright 1991 Mountain Math Software  */
/*  All Rights Reserved                    */
#include "adjust.h"
#include "travparm.h"

Adjustment::Adjustment(TraverseObject& obj, Command cmd, int32 Enlarge_Base,
	int32 Enlarge_Size, int New_Total, int Sequence_Index):
	Object(obj),
	TheCommand(cmd),
	EnlargeBase(Enlarge_Base),
	EnlargeSize(Enlarge_Size),
	NewTotal(New_Total),
	SequenceIndex(Sequence_Index)
{}

Adjustment::Adjustment(Adjustment& obj):
	Object(obj.GetTraverseObject()),
	EnlargeBase(obj.GetEnlargeBase()),
	EnlargeSize(obj.GetEnlargeSize()),
	NewTotal(obj.GetNewTotal()),
	SequenceIndex(obj.GetSequenceIndex()),
	PathIn(obj.GetInLink()),
	TheCommand(obj.GetCommand())
{
}

